@@ -25,7 +25,8 @@ import (
 )
 
 const (
-	operatorWait = 15 * time.Minute
+	operatorWait      = 15 * time.Minute
+	defaultSSHTimeout = 5 * time.Minute
 )
 
 func runCommandAndRetry(command string) string {
@@ -65,6 +66,20 @@ func masterNodes(oc *exutil.CLI) []*corev1.Node {
 	return nodes
 }
 
+func clusterNodes(oc *exutil.CLI) (masters, workers []*corev1.Node) {
+	nodes, err := oc.AdminKubeClient().CoreV1().Nodes().List(context.Background(), metav1.ListOptions{})
+	o.Expect(err).NotTo(o.HaveOccurred())
+	for i := range nodes.Items {
+		node := &nodes.Items[i]
+		if _, ok := node.Labels["node-role.kubernetes.io/master"]; ok {
+			masters = append(masters, node)
+		} else {
+			workers = append(workers, node)
+		}
+	}
+	return
+}
+
 func waitForMastersToUpdate(oc *exutil.CLI, mcps dynamic.NamespaceableResourceInterface) {
 	e2elog.Logf("Waiting for MachineConfig master to finish rolling out")
 	err := wait.Poll(30*time.Second, 30*time.Minute, func() (done bool, err error) {
@@ -182,50 +197,6 @@ func restartSDNPods(oc *exutil.CLI) {
 	o.Expect(err).NotTo(o.HaveOccurred())
 }
 
-func restartOpenshiftAPIPods(oc *exutil.CLI) {
-	e2elog.Logf("Restarting Openshift API server")
-
-	pods, err := oc.AdminKubeClient().CoreV1().Pods("openshift-apiserver").List(context.Background(), metav1.ListOptions{})
-	o.Expect(err).NotTo(o.HaveOccurred())
-
-	for _, pod := range pods.Items {
-		e2elog.Logf("Deleting pod %s", pod.Name)
-		err := oc.AdminKubeClient().CoreV1().Pods("openshift-apiserver").Delete(context.Background(), pod.Name, metav1.DeleteOptions{})
-		o.Expect(err).NotTo(o.HaveOccurred())
-	}
-
-	err = wait.Poll(10*time.Second, 5*time.Minute, func() (done bool, err error) {
-		apiServerDS, err := oc.AdminKubeClient().AppsV1().DaemonSets("openshift-apiserver").Get(context.Background(), "apiserver", metav1.GetOptions{})
-		if err != nil {
-			return false, nil
-		}
-		return apiServerDS.Status.NumberReady == apiServerDS.Status.NumberAvailable, nil
-	})
-	o.Expect(err).NotTo(o.HaveOccurred())
-}
-
-func restartMCDPods(oc *exutil.CLI) {
-	e2elog.Logf("Restarting MCD pods")
-
-	pods, err := oc.AdminKubeClient().CoreV1().Pods("openshift-machine-config-operator").List(context.Background(), metav1.ListOptions{})
-	o.Expect(err).NotTo(o.HaveOccurred())
-
-	for _, pod := range pods.Items {
-		e2elog.Logf("Deleting pod %s", pod.Name)
-		err := oc.AdminKubeClient().CoreV1().Pods("openshift-machine-config-operator").Delete(context.Background(), pod.Name, metav1.DeleteOptions{})
-		o.Expect(err).NotTo(o.HaveOccurred())
-	}
-
-	err = wait.Poll(10*time.Second, 5*time.Minute, func() (done bool, err error) {
-		mcDS, err := oc.AdminKubeClient().AppsV1().DaemonSets("openshift-machine-config-operator").Get(context.Background(), "machine-config-daemon", metav1.GetOptions{})
-		if err != nil {
-			return false, nil
-		}
-		return mcDS.Status.NumberReady == mcDS.Status.NumberAvailable, nil
-	})
-	o.Expect(err).NotTo(o.HaveOccurred())
-}
-
 func objects(from *objx.Value) []objx.Map {
 	var values []objx.Map
 	switch {
@@ -271,21 +242,42 @@ func countReady(items []corev1.Node) int {
 
 func fetchFileContents(node *corev1.Node, path string) string {
 	e2elog.Logf("Fetching %s file contents from %s", path, node.Name)
-	out, err := ssh(fmt.Sprintf("cat %q", path), node)
-	o.Expect(err).NotTo(o.HaveOccurred())
-	if len(out.Stderr) > 0 {
-		e2elog.Logf("file content stderr:\n%s", out.Stderr)
-	}
+	out := execOnNodeWithOutputOrFail(node, fmt.Sprintf("cat %q", path))
 	return out.Stdout
 }
 
-func expectSSH(cmd string, node *corev1.Node) {
-	e2elog.Logf("cmd[%s]: %s", node.Name, cmd)
-	out, err := e2essh.IssueSSHCommandWithResult(cmd, e2e.TestContext.Provider, node)
-	o.Expect(err).NotTo(o.HaveOccurred())
-	if len(out.Stderr) > 0 {
-		e2elog.Logf("command %q stderr:\n%s", cmd, out.Stderr)
-	}
+// execOnNodeWithOutputOrFail executes a command via ssh against a
+// node in a poll loop to ensure reliable execution in a disrupted
+// environment. The calling test will be failed if the command cannot
+// be executed successfully before the provided timeout.
+func execOnNodeWithOutputOrFail(node *corev1.Node, cmd string) *e2essh.Result {
+	var out *e2essh.Result
+	var err error
+	waitErr := wait.PollImmediate(5*time.Second, defaultSSHTimeout, func() (bool, error) {
+		out, err = e2essh.IssueSSHCommandWithResult(cmd, e2e.TestContext.Provider, node)
+		// IssueSSHCommandWithResult logs output
+		if err != nil {
+			e2elog.Logf("Failed to exec cmd [%s] on node %s: %v", cmd, node.Name, err)
+		}
+		return err == nil, nil
+	})
+	o.Expect(waitErr).NotTo(o.HaveOccurred())
+	return out
+}
+
+// execOnNodeOrFail executes a command via ssh against a node in a
+// poll loop until success or timeout. The output is ignored. The
+// calling test will be failed if the command cannot be executed
+// successfully before the timeout.
+func execOnNodeOrFail(node *corev1.Node, cmd string) {
+	_ = execOnNodeWithOutputOrFail(node, cmd)
+}
+
+// checkSSH repeatedly attempts to establish an ssh connection to a
+// node and fails the calling test if unable to establish the
+// connection before the default timeout.
+func checkSSH(node *corev1.Node) {
+	_ = execOnNodeWithOutputOrFail(node, "true")
 }
 
 func ssh(cmd string, node *corev1.Node) (*e2essh.Result, error) {
