@@ -1,27 +1,25 @@
 package operators
 
 import (
+	"context"
 	"fmt"
 	"strconv"
 	"time"
 
-	"k8s.io/client-go/kubernetes"
-
-	corev1 "k8s.io/api/core/v1"
-	"k8s.io/client-go/discovery"
-	"k8s.io/client-go/restmapper"
-	"k8s.io/client-go/scale"
-
 	g "github.com/onsi/ginkgo"
 	o "github.com/onsi/gomega"
+	"github.com/openshift/origin/test/extended/util/ibmcloud"
 	"github.com/stretchr/objx"
-
+	corev1 "k8s.io/api/core/v1"
 	metav1 "k8s.io/apimachinery/pkg/apis/meta/v1"
 	"k8s.io/apimachinery/pkg/runtime/schema"
+	"k8s.io/client-go/discovery"
 	"k8s.io/client-go/dynamic"
+	"k8s.io/client-go/kubernetes"
+	"k8s.io/client-go/restmapper"
+	"k8s.io/client-go/scale"
 	e2e "k8s.io/kubernetes/test/e2e/framework"
-
-	"github.com/openshift/origin/test/extended/util/ibmcloud"
+	e2eskipper "k8s.io/kubernetes/test/e2e/framework/skipper"
 )
 
 const (
@@ -39,7 +37,7 @@ func machineSetClient(dc dynamic.Interface) dynamic.ResourceInterface {
 // listWorkerMachineSets list all worker machineSets
 func listWorkerMachineSets(dc dynamic.Interface) ([]objx.Map, error) {
 	mc := machineSetClient(dc)
-	obj, err := mc.List(metav1.ListOptions{})
+	obj, err := mc.List(context.Background(), metav1.ListOptions{})
 	if err != nil {
 		return nil, err
 	}
@@ -70,7 +68,7 @@ func getNodesFromMachineSet(c *kubernetes.Clientset, dc dynamic.Interface, machi
 	}
 
 	// fetch nodes
-	allWorkerNodes, err := c.CoreV1().Nodes().List(metav1.ListOptions{
+	allWorkerNodes, err := c.CoreV1().Nodes().List(context.Background(), metav1.ListOptions{
 		LabelSelector: nodeLabelSelectorWorker,
 	})
 	if err != nil {
@@ -84,7 +82,7 @@ func getNodesFromMachineSet(c *kubernetes.Clientset, dc dynamic.Interface, machi
 	}
 	var nodes []*corev1.Node
 	for machineName := range machineToNodes {
-		node, err := c.CoreV1().Nodes().Get(machineToNodes[machineName], metav1.GetOptions{})
+		node, err := c.CoreV1().Nodes().Get(context.Background(), machineToNodes[machineName], metav1.GetOptions{})
 		if err != nil {
 			return nil, fmt.Errorf("failed to get worker nodes %q: %v", machineToNodes[machineName], err)
 		}
@@ -126,24 +124,24 @@ func scaleMachineSet(name string, replicas int) error {
 		return fmt.Errorf("error calling getScaleClient: %v", err)
 	}
 
-	scale, err := scaleClient.Scales(machineAPINamespace).Get(schema.GroupResource{Group: machineAPIGroup, Resource: "MachineSet"}, name)
+	scale, err := scaleClient.Scales(machineAPINamespace).Get(context.Background(), schema.GroupResource{Group: machineAPIGroup, Resource: "MachineSet"}, name, metav1.GetOptions{})
 	if err != nil {
 		return fmt.Errorf("error calling scaleClient.Scales get: %v", err)
 	}
 
 	scaleUpdate := scale.DeepCopy()
 	scaleUpdate.Spec.Replicas = int32(replicas)
-	_, err = scaleClient.Scales(machineAPINamespace).Update(schema.GroupResource{Group: machineAPIGroup, Resource: "MachineSet"}, scaleUpdate)
+	_, err = scaleClient.Scales(machineAPINamespace).Update(context.Background(), schema.GroupResource{Group: machineAPIGroup, Resource: "MachineSet"}, scaleUpdate, metav1.UpdateOptions{})
 	if err != nil {
 		return fmt.Errorf("error calling scaleClient.Scales update while setting replicas to %d: %v", err, replicas)
 	}
 	return nil
 }
 
-var _ = g.Describe("[Feature:Machines][Serial] Managed cluster should", func() {
+var _ = g.Describe("[sig-cluster-lifecycle][Feature:Machines][Serial] Managed cluster should", func() {
 	g.It("grow and decrease when scaling different machineSets simultaneously", func() {
 		if e2e.TestContext.Provider == ibmcloud.ProviderName {
-			e2e.Skipf("IBM Cloud clusters do not contain machineset resources")
+			e2eskipper.Skipf("IBM Cloud clusters do not contain machineset resources")
 		}
 
 		// expect new nodes to come up for machineSet
@@ -176,11 +174,11 @@ var _ = g.Describe("[Feature:Machines][Serial] Managed cluster should", func() {
 		machineSets, err := listWorkerMachineSets(dc)
 		o.Expect(err).NotTo(o.HaveOccurred())
 		if len(machineSets) == 0 {
-			e2e.Skipf("Expects at least one worker machineset. Found none!!!")
+			e2eskipper.Skipf("Expects at least one worker machineset. Found none!!!")
 		}
 
 		g.By("checking initial cluster workers size")
-		nodeList, err := c.CoreV1().Nodes().List(metav1.ListOptions{
+		nodeList, err := c.CoreV1().Nodes().List(context.Background(), metav1.ListOptions{
 			LabelSelector: nodeLabelSelectorWorker,
 		})
 		o.Expect(err).NotTo(o.HaveOccurred())
@@ -216,16 +214,47 @@ var _ = g.Describe("[Feature:Machines][Serial] Managed cluster should", func() {
 
 		g.By(fmt.Sprintf("waiting for cluster to get back to original size. Final size should be %d worker nodes", initialNumberOfWorkers))
 		o.Eventually(func() bool {
-			nodeList, err := c.CoreV1().Nodes().List(metav1.ListOptions{
+			nodeList, err := c.CoreV1().Nodes().List(context.Background(), metav1.ListOptions{
 				LabelSelector: nodeLabelSelectorWorker,
 			})
 			o.Expect(err).NotTo(o.HaveOccurred())
 			g.By(fmt.Sprintf("got %v nodes, expecting %v", len(nodeList.Items), initialNumberOfWorkers))
-			return len(nodeList.Items) == initialNumberOfWorkers
+			if len(nodeList.Items) != initialNumberOfWorkers {
+				return false
+			}
+
+			g.By(fmt.Sprintf("ensure worker is healthy"))
+			for _, node := range nodeList.Items {
+				for _, condition := range node.Status.Conditions {
+					switch condition.Type {
+					case corev1.NodeReady:
+						if condition.Status != corev1.ConditionTrue {
+							e2e.Logf("node/%s had unexpected condition %q == %v: %#v", node.Name, condition.Reason, condition.Status)
+							return false
+						}
+					case corev1.NodeMemoryPressure,
+						corev1.NodeDiskPressure,
+						corev1.NodePIDPressure,
+						corev1.NodeNetworkUnavailable:
+						if condition.Status != corev1.ConditionFalse {
+							e2e.Logf("node/%s had unexpected condition %q == %v: %#v", node.Name, condition.Reason, condition.Status)
+							return false
+						}
+
+					default:
+						e2e.Logf("node/%s had unhandled condition %q == %v: %#v", node.Name, condition.Reason, condition.Status)
+
+					}
+				}
+				e2e.Logf("node/%s conditions seem ok")
+			}
+
+			return true
 			// Azure actuator takes something over 3 minutes to delete a machine.
 			// The worst observable case to delete a machine was 5m15s however.
 			// Also, there are two instances to be deleted.
-			// Rounding to 7 minutes to accomodate for future new and slower cloud providers.
-		}, 7*time.Minute, 5*time.Second).Should(o.BeTrue())
+			// Rounding to 10 minutes to accommodate for future new and slower cloud providers.
+			// https://bugzilla.redhat.com/show_bug.cgi?id=1812240
+		}, 10*time.Minute, 5*time.Second).Should(o.BeTrue())
 	})
 })
